import pandas as pd
from ase.io import read

#data is stored in 'Co_dimer_data.csv' and 'Co_dimer_data_all.csv' file, which can be opened in text editors and excel. 
#'Co_dimer_data.csv' contains data used for machine learning
#'Co_dimer_data_all.csv' contains all data including declined samples

#The files contain the following columns:
#Lg1_Lg2: names of capping ligands as given in molSimplify library, one ligand meaning capping ligands on two sides are the same (Lg1=Lg2).
#xyz_filename_FM: file name of the optimized structure at FM spin state
#xyz_filename_AFM: file name of the optimized structure at AFM spin state
#E-AFM(a.u.): Energy of the optimzied structure at AFM spin state in atomic unit
#E-FM(a.u.): Energy of the optimzied structure at FM spin state in atomic unit
#DeltaE(meV): calculated energy differences between AFM and FM states in meV, this column is the data used in training the machine in the paper

#load the data into a pandas dataframe
# replace 'Co_dimer_data.csv' with 'Co_dimer_data_all.csv' to load all samples including declined ones
df=pd.read_csv('Co_dimer_data.csv',index_col=0)

#the optimized structures at both AFM and FM states are stored in '.xyz' files
#to load the structures into an ASE atoms object in the same order as the data
structures_FM=[]
structures_AFM=[]
for row in df.index:
 file_FM='structures_xyz/'+str(df.loc[row,'xyz_filename_FM'])
 structure_FM=read(file_FM)
 structures_FM.append(structure_FM)

 file_AFM='structures_xyz/'+str(df.loc[row,'xyz_filename_AFM'])
 structure_AFM=read(file_AFM)
 structures_AFM.append(structure_AFM)

#structures_FM and structures_AFM are lists of ASE atom object in the same order as the data

